.. image:: https://travis-ci.org/ambitioninc/django-issue.png
   :target: https://travis-ci.org/ambitioninc/django-issue

.. image:: https://coveralls.io/repos/ambitioninc/django-issue/badge.png?branch=develop
    :target: https://coveralls.io/r/ambitioninc/django-issue?branch=develop

.. image:: https://pypip.in/v/django-issue/badge.png
    :target: https://pypi.python.org/pypi/django-issue/
    :alt: Latest PyPI version

.. image:: https://pypip.in/d/django-issue/badge.png
    :target: https://pypi.python.org/pypi/django-issue/
    :alt: Number of PyPI downloads


django-issue
============

An app for tracking ongoing issues within your web application.

In a nutshell: a ticketing system for use by software components!

Installation
------------
To install the latest release, type::

    pip install django-issue

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-issue.git

Documentation
-------------

Full documentation is available at http://django-issue.readthedocs.org

License
-------
MIT License (see LICENSE)
